@@ -48,85 +48,89 @@ void ExtractPrince::execute() {
 	char *pathBuffer = (char *)malloc(17 * sizeof(char));
 	printf("Unpacking The Prince and the Coward text data... \n");
 
-	std::string fullName = mainDir.getFullPath();
+	std::string databankFullName = mainDir.getFullPath();
 	sprintf(pathBuffer, "all/databank.ptc");
-	fullName += pathBuffer;
-	Common::Filename filename(fullName);
-	_databank.open(filename, "rb");
-	if (!_databank.isOpen()) {
-		_fFiles.close();
-		error("Unable to open all/databank.ptc");
-	}
-	byte *fileTable = openDatabank();
-	bool mobsDE = false;
-	for (size_t i = 0; i < _items.size(); i++) {
-		if (!scumm_stricmp(_items[i]._name.c_str(), "variatxt.dat")) {
-			exportVariaTxt(loadFile(i));
+	databankFullName += pathBuffer;
+	Common::Filename filename(databankFullName);
+	// Trying to access the DATABANK files
+	// Here we check if the File all/databank.ptc exists.
+	// If so, we load it and extract the data from the databanks.
+	//
+	// If the databank.ptc file is not found, we try to access the
+	// uncompressed files directly.
+	if (Common::Filename(databankFullName).exists()) {
+		_databank.open(filename, "rb");
+		printf("DATABANK.PTC loaded, processing... \n");
+		byte *fileTable = openDatabank();
+		bool mobsDE = false;
+		for (size_t i = 0; i < _items.size(); i++) {
+			if (!scumm_stricmp(_items[i]._name.c_str(), "variatxt.dat")) {
+				exportVariaTxt(loadFile(i));
+			}
+			if (!scumm_stricmp(_items[i]._name.c_str(), "invtxt.dat")) {
+				exportInvTxt(loadFile(i));
+			}
+			if (!scumm_stricmp(_items[i]._name.c_str(), "talktxt.dat")) {
+				exportTalkTxt(loadFile(i));
+			}
+			if (!scumm_stricmp(_items[i]._name.c_str(), "credits.dat")) {
+				exportCredits(loadFile(i));
+			}
+			if (!scumm_stricmp(_items[i]._name.c_str(), "mob01.lst")) {
+				// For DE game data
+				mobsDE = true;
+				_outputPath.setFullName("mob.txt");
+				_fFiles.open(_outputPath, "w");
+				if (!_fFiles.isOpen()) {
+					error("Unable to create mob.txt");
+				}
+				_fFiles.print("mob.lst\nmob_name - exam text\n");
+				int loc = 0;
+				for (int j = 1; j <= kNumberOfLocations; j++) {
+					_fFiles.print("%d.\n", j);
+					// no databanks for loc 44 and 45
+					if (j != 44 && j != 45) {
+						exportMobs(loadFile(i + loc));
+						loc++;
+					}
+				}
+				printf("mob.txt - done\n");
+				printf("All done!\n");
+				free(pathBuffer);
+				_fFiles.close();
+			}
 		}
-		if (!scumm_stricmp(_items[i]._name.c_str(), "invtxt.dat")) {
-			exportInvTxt(loadFile(i));
-		}
-		if (!scumm_stricmp(_items[i]._name.c_str(), "talktxt.dat")) {
-			exportTalkTxt(loadFile(i));
-		}
-		if (!scumm_stricmp(_items[i]._name.c_str(), "credits.dat")) {
-			exportCredits(loadFile(i));
-		}
-		if (!scumm_stricmp(_items[i]._name.c_str(), "mob01.lst")) {
-			// For DE game data
-			mobsDE = true;
+		free(fileTable);
+		_databank.close();
+		_items.clear();
+
+		// For PL game data
+		if (!mobsDE) {
 			_outputPath.setFullName("mob.txt");
 			_fFiles.open(_outputPath, "w");
 			if (!_fFiles.isOpen()) {
 				error("Unable to create mob.txt");
 			}
 			_fFiles.print("mob.lst\nmob_name - exam text\n");
-			int loc = 0;
-			for (int j = 1; j <= kNumberOfLocations; j++) {
-				_fFiles.print("%d.\n", j);
+			for (int loc = 1; loc <= kNumberOfLocations; loc++) {
+				_fFiles.print("%d.\n", loc);
 				// no databanks for loc 44 and 45
-				if (j != 44 && j != 45) {
-					exportMobs(loadFile(i + loc));
-					loc++;
-				}
-			}
-			printf("mob.txt - done\n");
-			printf("All done!\n");
-			free(pathBuffer);
-			_fFiles.close();
-		}
-	}
-	free(fileTable);
-	_databank.close();
-	_items.clear();
-
-	// For PL game data
-	if (!mobsDE) {
-		_outputPath.setFullName("mob.txt");
-		_fFiles.open(_outputPath, "w");
-		if (!_fFiles.isOpen()) {
-			error("Unable to create mob.txt");
-		}
-		_fFiles.print("mob.lst\nmob_name - exam text\n");
-		for (int loc = 1; loc <= kNumberOfLocations; loc++) {
-			_fFiles.print("%d.\n", loc);
-			// no databanks for loc 44 and 45
-			if (loc != 44 && loc != 45) {
-				fullName = mainDir.getFullPath();
-				sprintf(pathBuffer, "%02d/databank.ptc", loc);
-				fullName += pathBuffer;
-				filename = Common::Filename(fullName);
-				_databank.open(filename, "rb");
-				if (!_databank.isOpen()) {
-					_fFiles.close();
-					error("Unable to open %02d/databank.ptc", loc);
-				}
-				fileTable = openDatabank();
-				for (size_t i = 0; i < _items.size(); i++) {
-					if (!scumm_stricmp(_items[i]._name.c_str(), "mob.lst")) {
-						exportMobs(loadFile(i));
+				if (loc != 44 && loc != 45) {
+					databankFullName = mainDir.getFullPath();
+					sprintf(pathBuffer, "%02d/databank.ptc", loc);
+					databankFullName += pathBuffer;
+					filename = Common::Filename(databankFullName);
+					_databank.open(filename, "rb");
+					if (!_databank.isOpen()) {
+						_fFiles.close();
+						error("Unable to open %02d/databank.ptc", loc);
+					}
+					fileTable = openDatabank();
+					for (size_t i = 0; i < _items.size(); i++) {
+						if (!scumm_stricmp(_items[i]._name.c_str(), "mob.lst")) {
+							exportMobs(loadFile(i));
+						}
 					}
-				}
 				free(fileTable);
 				_databank.close();
 				_items.clear();
@@ -136,15 +140,49 @@ void ExtractPrince::execute() {
 		printf("All done!\n");
 		free(pathBuffer);
 		_fFiles.close();
+		}
+	}
+	if (Common::Filename(databankFullName).exists() == false) {
+		printf("Unable to load DATABANK.PTC. Trying to access the uncompressed data files... \n");
+
+		// Since we found out that there's no databank.ptc file, we now
+		// try to extract the data from the uncompressed datafiles.
+		printf("Processing variatxt.dat...\n");
+		exportVariaTxt(loadFile(mainDir.getFullPath() + "variatxt.dat"));
+		printf("Processing invtxt.dat...\n");
+		exportInvTxt(loadFile(mainDir.getFullPath() + "invtxt.dat"));
+		printf("Processing talktxt.dat...\n");
+		exportTalkTxt(loadFile(mainDir.getFullPath() + "talktxt.dat"));
+		printf("Processing credits.dat...\n");
+		exportCredits(loadFile(mainDir.getFullPath() + "credits.dat"));
+
+		// Process the mob*.lst files. We have up to 61 files, so we process them recursively.
+		_outputPath.setFullName("mob.txt");
+		_fFiles.open(_outputPath, "w");
+		_fFiles.print("mob.lst\nmob_name - exam text\n");
+
+		int mobFileNumber;
+		for (mobFileNumber = 1; mobFileNumber <= 9; ++mobFileNumber) {
+			if (Common::Filename(mainDir.getFullPath() + "mob0" + std::to_string(mobFileNumber) + ".lst").exists() == true) {
+				_fFiles.print("%d.\n", mobFileNumber);
+				exportMobs(loadFile(mainDir.getFullPath() + "mob0" + std::to_string(mobFileNumber) + ".lst"));
+				print("Processing mob0%d.lst", mobFileNumber);
+			}
+		}
+		for (mobFileNumber = 10; mobFileNumber <= 61; ++mobFileNumber) {
+			if (Common::Filename(mainDir.getFullPath() + "mob" + std::to_string(mobFileNumber) + ".lst").exists() == true) {
+				_fFiles.print("%d.\n", mobFileNumber);
+				exportMobs(loadFile(mainDir.getFullPath() + "mob" + std::to_string(mobFileNumber) + ".lst"));
+				print("Processing mob%d.lst...", mobFileNumber);
+			}
+		}
+		_fFiles.close();
+		printf("mob.txt - done\n");
+		printf("All done!\n");
 	}
 }
-
 InspectionMatch ExtractPrince::inspectInput(const Common::Filename &filename) {
-	std::string file = filename.getFullName();
-	if (scumm_stricmp(file.c_str(), "databank.ptc") == 0) {
-		return IMATCH_PERFECT;
-	}
-	return IMATCH_AWFUL;
+	return IMATCH_PERFECT;
 }
 
 byte *ExtractPrince::openDatabank() {
@@ -180,6 +218,7 @@ void ExtractPrince::decrypt(byte *buffer, uint32 size) {
 	}
 }
 
+// DATABANK loader
 ExtractPrince::FileData ExtractPrince::loadFile(int itemIndex) {
 	FileData fileData;
 	fileData._fileTable = 0;
@@ -210,6 +249,22 @@ ExtractPrince::FileData ExtractPrince::loadFile(int itemIndex) {
 
 	return fileData;
 }
+// Uncompressed datafile loader
+ExtractPrince::FileData ExtractPrince::loadFile(std::string fileName) {
+	Common::File file;
+	file.open(fileName, "rb");
+	if (!file.isOpen()) {
+		error("Unable to open datafile %s", fileName.c_str());
+	}
+	FileData fileData;
+	fileData._size = file.size();
+	fileData._fileTable = 0;
+
+	fileData._fileTable = (byte *)malloc(fileData._size);
+	file.read_throwsOnError(fileData._fileTable, fileData._size);
+
+	return fileData;
+}
 
 void ExtractPrince::exportMobs(FileData fileData) {
 	if (fileData._fileTable != 0) {
@@ -496,7 +551,7 @@ byte *ExtractPrince::talkTxtWithDialog(byte *talkTxt) {
 		mainString++;
 	}
 	_fFiles.print("#END\n");
-			
+
 	for (int i = 0; i < dialogBox; i++) {
 		_fFiles.print("@DIALOG_BOX %d\n", i);
 		while ((c = *dialogBoxAddr[i]) != 255) {
@@ -555,7 +610,7 @@ byte *ExtractPrince::talkTxtNoDialog(byte *talkTxt) {
 	return talkTxt;
 }
 
-// Returns 'true' if next char is a value for 'enable option', 
+// Returns 'true' if next char is a value for 'enable option',
 // 'disable option', 'show dialog box", 'flag code' or 'exit code'
 bool ExtractPrince::printSpecialDialogData(byte c) {
 	switch (c) {
@@ -645,145 +700,145 @@ char ExtractPrince::correctPolishLetter(char c) {
 
 // John_Doe's implementation
 static const uint16 table1[] = {
-    0x8000, 0x0002,
-    0x4000, 0x0004,
-    0x2000, 0x0008,
-    0x1000, 0x0010,
-    0x0800, 0x0020,
-    0x0400, 0x0040,
-    0x0200, 0x0080,
-    0x0100, 0x0100,
-    0x0080, 0x0200,
-    0x0040, 0x0400
+	0x8000, 0x0002,
+	0x4000, 0x0004,
+	0x2000, 0x0008,
+	0x1000, 0x0010,
+	0x0800, 0x0020,
+	0x0400, 0x0040,
+	0x0200, 0x0080,
+	0x0100, 0x0100,
+	0x0080, 0x0200,
+	0x0040, 0x0400
 };
 
 static const uint32 table2[] = {
-    0x0000F000,
-    0x0020FC00,
-    0x00A0FF00,
-    0x02A0FF80,
-    0x06A0FFC0,
-    0x0EA0FFE0,
-    0x1EA0FFF0,
-    0x3EA0FFF8
+	0x0000F000,
+	0x0020FC00,
+	0x00A0FF00,
+	0x02A0FF80,
+	0x06A0FFC0,
+	0x0EA0FFE0,
+	0x1EA0FFF0,
+	0x3EA0FFF8
 };
 
 static const uint16 table3[] = {
-    0x8000, 0x0000,
-    0x4000, 0x0002,
-    0x2000, 0x0006,
-    0x1000, 0x000E,
-    0x0800, 0x001E,
-    0x0400, 0x003E,
-    0x0200, 0x007E,
-    0x0100, 0x00FE,
-    0x0080, 0x01FE,
-    0x0040, 0x03FE,
-    0x0020, 0x07FE,
-    0x0010, 0x0FFE,
-    0x0008, 0x1FFE,
-    0x0004, 0x3FFE,
-    0x0002, 0x7FFE,
-    0x0001, 0xFFFE
+	0x8000, 0x0000,
+	0x4000, 0x0002,
+	0x2000, 0x0006,
+	0x1000, 0x000E,
+	0x0800, 0x001E,
+	0x0400, 0x003E,
+	0x0200, 0x007E,
+	0x0100, 0x00FE,
+	0x0080, 0x01FE,
+	0x0040, 0x03FE,
+	0x0020, 0x07FE,
+	0x0010, 0x0FFE,
+	0x0008, 0x1FFE,
+	0x0004, 0x3FFE,
+	0x0002, 0x7FFE,
+	0x0001, 0xFFFE
 };
 
 void Decompressor::decompress(byte *source, byte *dest, uint32 destSize) {
-    byte *destEnd = dest + destSize;
-    int more;
-    _src = source;
-    _dst = dest;
-    _bitBuffer = 0x80;
-    while (_dst < destEnd) {
-        uint32 ebp;
-        uint16 offset, length;
-        if (getBit()) {
-            if (getBit()) {
-                if (getBit()) {
-                    if (getBit()) {
-                        if (getBit()) {
-                            if (getBit()) {
-                                uint32 tableIndex = 0;
-                                while (getBit())
-                                    tableIndex++;
-                                length = table3[tableIndex * 2 + 0];
-                                do {
-                                    more = !(length & 0x8000);
-                                    length = (length << 1) | getBit();
-                                } while (more);
-                                length += table3[tableIndex * 2 + 1];
-                                length++;
-                                memcpy(_dst, _src, length);
-                                _src += length;
-                                _dst += length;
-                            }
-                            *_dst++ = *_src++;
-                        }
-                        *_dst++ = *_src++;
-                    }
-                    *_dst++ = *_src++;
-                }
-                *_dst++ = *_src++;
-            }
-            *_dst++ = *_src++;
-        }
-        if (!getBit()) {
-            if (getBit()) {
-                uint32 tableIndex = getBit();
-                tableIndex = (tableIndex << 1) | getBit();
-                tableIndex = (tableIndex << 1) | getBit();
-                ebp = table2[tableIndex];
-                length = 1;
-            } else {
-                ebp = 0x0000FF00;
-                length = 0;
-            }
-        } else {
-            uint32 tableIndex = 0;
-            while (getBit())
-                tableIndex++;
-            length = table1[tableIndex * 2 + 0];
-            do {
-                more = !(length & 0x8000);
-                length = (length << 1) | getBit();
-            } while (more);
-            length += table1[tableIndex * 2 + 1];
-            tableIndex = getBit();
-            tableIndex = (tableIndex << 1) | getBit();
-            tableIndex = (tableIndex << 1) | getBit();
-            ebp = table2[tableIndex];
-        }
-        offset = ebp & 0xFFFF;
-        do {
-            if (_bitBuffer == 0x80) {
-                if (offset >= 0xFF00) {
-                    offset = (offset << 8) | *_src++;
-                }
-            }
-            more = offset & 0x8000;
-            offset = (offset << 1) | getBit();
-        } while (more);
-        offset += (ebp >> 16);
-        length += 2;
-        while (length--) {
-            if (_dst >= destEnd) {
-                return;
-            }
-            *_dst = *(_dst - offset);
-            _dst++;
-        }
-    }
+	byte *destEnd = dest + destSize;
+	int more;
+	_src = source;
+	_dst = dest;
+	_bitBuffer = 0x80;
+	while (_dst < destEnd) {
+		uint32 ebp;
+		uint16 offset, length;
+		if (getBit()) {
+			if (getBit()) {
+				if (getBit()) {
+					if (getBit()) {
+						if (getBit()) {
+							if (getBit()) {
+								uint32 tableIndex = 0;
+								while (getBit())
+									tableIndex++;
+								length = table3[tableIndex * 2 + 0];
+								do {
+									more = !(length & 0x8000);
+									length = (length << 1) | getBit();
+								} while (more);
+								length += table3[tableIndex * 2 + 1];
+								length++;
+								memcpy(_dst, _src, length);
+								_src += length;
+								_dst += length;
+							}
+							*_dst++ = *_src++;
+						}
+						*_dst++ = *_src++;
+					}
+					*_dst++ = *_src++;
+				}
+				*_dst++ = *_src++;
+			}
+			*_dst++ = *_src++;
+		}
+		if (!getBit()) {
+			if (getBit()) {
+				uint32 tableIndex = getBit();
+				tableIndex = (tableIndex << 1) | getBit();
+				tableIndex = (tableIndex << 1) | getBit();
+				ebp = table2[tableIndex];
+				length = 1;
+			} else {
+				ebp = 0x0000FF00;
+				length = 0;
+			}
+		} else {
+			uint32 tableIndex = 0;
+			while (getBit())
+				tableIndex++;
+			length = table1[tableIndex * 2 + 0];
+			do {
+				more = !(length & 0x8000);
+				length = (length << 1) | getBit();
+			} while (more);
+			length += table1[tableIndex * 2 + 1];
+			tableIndex = getBit();
+			tableIndex = (tableIndex << 1) | getBit();
+			tableIndex = (tableIndex << 1) | getBit();
+			ebp = table2[tableIndex];
+		}
+		offset = ebp & 0xFFFF;
+		do {
+			if (_bitBuffer == 0x80) {
+				if (offset >= 0xFF00) {
+					offset = (offset << 8) | *_src++;
+				}
+			}
+			more = offset & 0x8000;
+			offset = (offset << 1) | getBit();
+		} while (more);
+		offset += (ebp >> 16);
+		length += 2;
+		while (length--) {
+			if (_dst >= destEnd) {
+				return;
+			}
+			*_dst = *(_dst - offset);
+			_dst++;
+		}
+	}
 }
 
 int Decompressor::getBit() {
-    int bit = (_bitBuffer & 0x80) >> 7;
-    _bitBuffer <<= 1;
-    if (_bitBuffer == 0) {
-        _bitBuffer = *_src++;
-        bit = (_bitBuffer & 0x80) >> 7;
-        _bitBuffer <<= 1;
-        _bitBuffer |= 1;
-    }
-    return bit;
+	int bit = (_bitBuffer & 0x80) >> 7;
+	_bitBuffer <<= 1;
+	if (_bitBuffer == 0) {
+		_bitBuffer = *_src++;
+		bit = (_bitBuffer & 0x80) >> 7;
+		_bitBuffer <<= 1;
+		_bitBuffer |= 1;
+	}
+	return bit;
 }
 
 #ifdef STANDALONE_MAIN
